@@ -42,7 +42,7 @@
 //! The entry point for most customers will be [`Client`]. [`Client`] exposes one method for each API offered
 //! by the service.
 //!
-//! Some APIs require complex or nested arguments. These exist in [`model`].
+//! Some APIs require complex or nested arguments. These exist in [`model`](crate::model).
 //!
 //! Lastly, errors that can be returned by the service are contained within [`error`]. [`Error`] defines a meta
 //! error encompassing all possible errors that can be returned by the service.
@@ -67,6 +67,8 @@ pub mod input;
 mod json_deser;
 mod json_errors;
 mod json_ser;
+/// Generated accessors for nested fields
+mod lens;
 pub mod middleware;
 /// Data structures used by operation inputs/outputs.
 pub mod model;
@@ -77,6 +79,8 @@ mod operation_deser;
 mod operation_ser;
 /// Output structures for operations.
 pub mod output;
+/// Paginators for the service
+pub mod paginator;
 /// Crate version number.
 pub static PKG_VERSION: &str = env!("CARGO_PKG_VERSION");
 pub use aws_smithy_http::byte_stream::ByteStream;
